==> haskell-binary-parser-0.5.7.6-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 binary-parser
version:              0.5.7.6
visibility:           public
id:                   binary-parser-0.5.7.6-6CJtaLVJtxo2SAw2PIRE3w
key:                  binary-parser-0.5.7.6-6CJtaLVJtxo2SAw2PIRE3w
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/binary-parser
synopsis:
    An efficient but limited parser API specialised to bytestrings

category:             Parser, Binary
abi:                  aa43249ee5d09c227dba8bfa5deeb469
exposed:              True
exposed-modules:      BinaryParser
hidden-modules:       BinaryParser.Prelude
import-dirs:          /usr/lib/ghc-9.0.2/site-local/binary-parser-0.5.7.6
library-dirs:         /usr/lib/ghc-9.0.2/site-local/binary-parser-0.5.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-parser
hs-libraries:         HSbinary-parser-0.5.7.6-6CJtaLVJtxo2SAw2PIRE3w
depends:
    base-4.15.1.0 bytestring-0.10.12.1 mtl-2.2.2 text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-binary-parser/html/binary-parser.haddock

haddock-html:         /usr/share/doc/haskell-binary-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-parser-0.5.7.6-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 binary-parser
version:              0.5.7.6
visibility:           public
id:                   binary-parser-0.5.7.6-LBPQUeTjkXII6P0Ne5D94Y
key:                  binary-parser-0.5.7.6-LBPQUeTjkXII6P0Ne5D94Y
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/binary-parser
synopsis:
    An efficient but limited parser API specialised to bytestrings

category:             Parser, Binary
abi:                  c25b717445dc41a6f86757bd48ae632b
exposed:              True
exposed-modules:      BinaryParser
hidden-modules:       BinaryParser.Prelude
import-dirs:          /usr/lib/ghc-9.2.8/site-local/binary-parser-0.5.7.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/binary-parser-0.5.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-binary-parser
hs-libraries:         HSbinary-parser-0.5.7.6-LBPQUeTjkXII6P0Ne5D94Y
depends:
    base-4.16.4.0 bytestring-0.11.4.0 mtl-2.2.2 text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-binary-parser/html/binary-parser.haddock

haddock-html:         /usr/share/doc/haskell-binary-parser/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
